{% extends 'generic/object.html' %} {% block content %}
<div class="row mb-3">
  <div class="col col-md-6">
    <div class="card">
      <h5 class="card-header">Unacceptable event relation</h5>
      <div class="card-body">
        <table class="table table-hover attr-table">
          <tr>
            <th scope="row">Name</th>
            <td>{{ object.name }}</td>
          </tr>
          <tr>
            <th scope="row">Description</th>
            <td>{{ object.description }}</td>
          </tr>
        </table>
      </div>
    </div>
    {% include 'inc/panels/custom_fields.html' %}
  </div>
  <div class="col col-md-6">{% include 'inc/panels/tags.html' %}</div>
</div>
{% endblock content %}
